import { useChat } from "@ai-sdk/react";
import { createFileRoute } from "@tanstack/react-router";

export const Route = createFileRoute("/chats/$agentName")({
  loader: ({ params }) => params,
  component: Chat,
});

function Chat() {
  const { agentName } = Route.useParams();
  const { messages, input, handleInputChange, handleSubmit } = useChat(
    /*{
    api: "http://localhost:8787/api/chat",
  }*/ { api: `/api/chat/${agentName}` }
  );
  return (
    <div className="flex flex-col w-full max-w-md py-24 mx-auto stretch">
      {messages.map((message) => (
        <div key={message.id} className="whitespace-pre-wrap">
          {message.role === "user" ? "User: " : "AI: "}
          {message.parts.map((part, i) => {
            switch (part.type) {
              case "text":
                return <div key={`${message.id}-${i}`}>{part.text}</div>;
              case "tool-invocation":
                return (
                  <pre key={`${message.id}-${i}`}>
                    {JSON.stringify(part.toolInvocation, null, 2)}
                  </pre>
                );
              case "reasoning":
                return (
                  <div key={`${message.id}-${i}`}>
                    (Reasoning) {part.reasoning}
                  </div>
                );
              case "step-start":
                return (
                  <div key={`${message.id}-${i}`}>
                    (Step Start) {JSON.stringify(part)}
                  </div>
                );
              case "source":
                return (
                  <div key={`${message.id}-${i}`}>
                    (Source) {JSON.stringify(part.source)}
                  </div>
                );
              case "file":
                return (
                  <div key={`${message.id}-${i}`}>
                    <span>(File)</span>
                    <a href={part.data}>{part.mimeType}</a>
                  </div>
                );
              default:
                return (
                  <div key={`${message.id}-${i}`}>
                    (?) {JSON.stringify(part)}
                  </div>
                );
            }
          })}
        </div>
      ))}

      <form onSubmit={handleSubmit}>
        <input
          className="fixed dark:bg-zinc-900 bottom-0 w-full max-w-md p-2 mb-8 border border-zinc-300 dark:border-zinc-800 rounded shadow-xl"
          value={input}
          placeholder="Say something..."
          onChange={handleInputChange}
        />
      </form>
    </div>
  );
}
